| Copyright | (c) 2013-2015 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.CloudWatchLogs.Types
Contents
Description
- cloudWatchLogs :: Service
- _InvalidParameterException :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidSequenceTokenException :: AsError a => Getting (First ServiceError) a ServiceError
- _ResourceAlreadyExistsException :: AsError a => Getting (First ServiceError) a ServiceError
- _OperationAbortedException :: AsError a => Getting (First ServiceError) a ServiceError
- _DataAlreadyAcceptedException :: AsError a => Getting (First ServiceError) a ServiceError
- _ServiceUnavailableException :: AsError a => Getting (First ServiceError) a ServiceError
- _ResourceNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError
- _LimitExceededException :: AsError a => Getting (First ServiceError) a ServiceError
- data OrderBy
- data Destination
- destination :: Destination
- dTargetARN :: Lens' Destination (Maybe Text)
- dCreationTime :: Lens' Destination (Maybe Natural)
- dArn :: Lens' Destination (Maybe Text)
- dAccessPolicy :: Lens' Destination (Maybe Text)
- dDestinationName :: Lens' Destination (Maybe Text)
- dRoleARN :: Lens' Destination (Maybe Text)
- data FilteredLogEvent
- filteredLogEvent :: FilteredLogEvent
- fleIngestionTime :: Lens' FilteredLogEvent (Maybe Natural)
- fleLogStreamName :: Lens' FilteredLogEvent (Maybe Text)
- fleMessage :: Lens' FilteredLogEvent (Maybe Text)
- fleTimestamp :: Lens' FilteredLogEvent (Maybe Natural)
- fleEventId :: Lens' FilteredLogEvent (Maybe Text)
- data InputLogEvent
- inputLogEvent :: Natural -> Text -> InputLogEvent
- ileTimestamp :: Lens' InputLogEvent Natural
- ileMessage :: Lens' InputLogEvent Text
- data LogGroup
- logGroup :: LogGroup
- lgCreationTime :: Lens' LogGroup (Maybe Natural)
- lgMetricFilterCount :: Lens' LogGroup (Maybe Int)
- lgArn :: Lens' LogGroup (Maybe Text)
- lgLogGroupName :: Lens' LogGroup (Maybe Text)
- lgRetentionInDays :: Lens' LogGroup (Maybe Int)
- lgStoredBytes :: Lens' LogGroup (Maybe Natural)
- data LogStream
- logStream :: LogStream
- lsCreationTime :: Lens' LogStream (Maybe Natural)
- lsUploadSequenceToken :: Lens' LogStream (Maybe Text)
- lsArn :: Lens' LogStream (Maybe Text)
- lsFirstEventTimestamp :: Lens' LogStream (Maybe Natural)
- lsLogStreamName :: Lens' LogStream (Maybe Text)
- lsStoredBytes :: Lens' LogStream (Maybe Natural)
- lsLastIngestionTime :: Lens' LogStream (Maybe Natural)
- lsLastEventTimestamp :: Lens' LogStream (Maybe Natural)
- data MetricFilter
- metricFilter :: MetricFilter
- mfCreationTime :: Lens' MetricFilter (Maybe Natural)
- mfFilterName :: Lens' MetricFilter (Maybe Text)
- mfFilterPattern :: Lens' MetricFilter (Maybe Text)
- mfMetricTransformations :: Lens' MetricFilter (Maybe (NonEmpty MetricTransformation))
- data MetricFilterMatchRecord
- metricFilterMatchRecord :: MetricFilterMatchRecord
- mfmrExtractedValues :: Lens' MetricFilterMatchRecord (HashMap Text Text)
- mfmrEventMessage :: Lens' MetricFilterMatchRecord (Maybe Text)
- mfmrEventNumber :: Lens' MetricFilterMatchRecord (Maybe Integer)
- data MetricTransformation
- metricTransformation :: Text -> Text -> Text -> MetricTransformation
- mtMetricName :: Lens' MetricTransformation Text
- mtMetricNamespace :: Lens' MetricTransformation Text
- mtMetricValue :: Lens' MetricTransformation Text
- data OutputLogEvent
- outputLogEvent :: OutputLogEvent
- oleIngestionTime :: Lens' OutputLogEvent (Maybe Natural)
- oleMessage :: Lens' OutputLogEvent (Maybe Text)
- oleTimestamp :: Lens' OutputLogEvent (Maybe Natural)
- data RejectedLogEventsInfo
- rejectedLogEventsInfo :: RejectedLogEventsInfo
- rleiTooOldLogEventEndIndex :: Lens' RejectedLogEventsInfo (Maybe Int)
- rleiTooNewLogEventStartIndex :: Lens' RejectedLogEventsInfo (Maybe Int)
- rleiExpiredLogEventEndIndex :: Lens' RejectedLogEventsInfo (Maybe Int)
- data SearchedLogStream
- searchedLogStream :: SearchedLogStream
- slsLogStreamName :: Lens' SearchedLogStream (Maybe Text)
- slsSearchedCompletely :: Lens' SearchedLogStream (Maybe Bool)
- data SubscriptionFilter
- subscriptionFilter :: SubscriptionFilter
- sfCreationTime :: Lens' SubscriptionFilter (Maybe Natural)
- sfFilterName :: Lens' SubscriptionFilter (Maybe Text)
- sfDestinationARN :: Lens' SubscriptionFilter (Maybe Text)
- sfLogGroupName :: Lens' SubscriptionFilter (Maybe Text)
- sfFilterPattern :: Lens' SubscriptionFilter (Maybe Text)
- sfRoleARN :: Lens' SubscriptionFilter (Maybe Text)
Service Configuration
cloudWatchLogs :: Service Source
API version '2014-03-28' of the Amazon CloudWatch Logs SDK configuration.
Errors
_InvalidParameterException :: AsError a => Getting (First ServiceError) a ServiceError Source
Returned if a parameter of the request is incorrectly specified.
_InvalidSequenceTokenException :: AsError a => Getting (First ServiceError) a ServiceError Source
Prism for InvalidSequenceTokenException' errors.
_ResourceAlreadyExistsException :: AsError a => Getting (First ServiceError) a ServiceError Source
Returned if the specified resource already exists.
_OperationAbortedException :: AsError a => Getting (First ServiceError) a ServiceError Source
Returned if multiple requests to update the same resource were in conflict.
_DataAlreadyAcceptedException :: AsError a => Getting (First ServiceError) a ServiceError Source
Prism for DataAlreadyAcceptedException' errors.
_ServiceUnavailableException :: AsError a => Getting (First ServiceError) a ServiceError Source
Returned if the service cannot complete the request.
_ResourceNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError Source
Returned if the specified resource does not exist.
_LimitExceededException :: AsError a => Getting (First ServiceError) a ServiceError Source
Returned if you have reached the maximum number of resources that can be created.
OrderBy
Constructors
| LastEventTime | |
| LogStreamName |
Destination
data Destination Source
See: destination smart constructor.
destination :: Destination Source
Creates a value of Destination with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
dTargetARN :: Lens' Destination (Maybe Text) Source
Undocumented member.
dCreationTime :: Lens' Destination (Maybe Natural) Source
Undocumented member.
dAccessPolicy :: Lens' Destination (Maybe Text) Source
Undocumented member.
dDestinationName :: Lens' Destination (Maybe Text) Source
Undocumented member.
FilteredLogEvent
data FilteredLogEvent Source
Represents a matched event from a FilterLogEvents request.
See: filteredLogEvent smart constructor.
filteredLogEvent :: FilteredLogEvent Source
Creates a value of FilteredLogEvent with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
fleIngestionTime :: Lens' FilteredLogEvent (Maybe Natural) Source
Undocumented member.
fleLogStreamName :: Lens' FilteredLogEvent (Maybe Text) Source
The name of the log stream this event belongs to.
fleMessage :: Lens' FilteredLogEvent (Maybe Text) Source
The data contained in the log event.
fleTimestamp :: Lens' FilteredLogEvent (Maybe Natural) Source
Undocumented member.
fleEventId :: Lens' FilteredLogEvent (Maybe Text) Source
A unique identifier for this event.
InputLogEvent
data InputLogEvent Source
A log event is a record of some activity that was recorded by the application or resource being monitored. The log event record that Amazon CloudWatch Logs understands contains two properties: the timestamp of when the event occurred, and the raw event message.
See: inputLogEvent smart constructor.
Arguments
| :: Natural | |
| -> Text | |
| -> InputLogEvent |
Creates a value of InputLogEvent with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ileTimestamp :: Lens' InputLogEvent Natural Source
Undocumented member.
ileMessage :: Lens' InputLogEvent Text Source
Undocumented member.
LogGroup
See: logGroup smart constructor.
Creates a value of LogGroup with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lgCreationTime :: Lens' LogGroup (Maybe Natural) Source
Undocumented member.
lgStoredBytes :: Lens' LogGroup (Maybe Natural) Source
Undocumented member.
LogStream
A log stream is sequence of log events from a single emitter of logs.
See: logStream smart constructor.
Creates a value of LogStream with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lsCreationTime :: Lens' LogStream (Maybe Natural) Source
Undocumented member.
lsFirstEventTimestamp :: Lens' LogStream (Maybe Natural) Source
Undocumented member.
lsStoredBytes :: Lens' LogStream (Maybe Natural) Source
Undocumented member.
lsLastIngestionTime :: Lens' LogStream (Maybe Natural) Source
Undocumented member.
lsLastEventTimestamp :: Lens' LogStream (Maybe Natural) Source
Undocumented member.
MetricFilter
data MetricFilter Source
Metric filters can be used to express how Amazon CloudWatch Logs would extract metric observations from ingested log events and transform them to metric data in a CloudWatch metric.
See: metricFilter smart constructor.
metricFilter :: MetricFilter Source
Creates a value of MetricFilter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
mfCreationTime :: Lens' MetricFilter (Maybe Natural) Source
Undocumented member.
mfFilterName :: Lens' MetricFilter (Maybe Text) Source
Undocumented member.
mfFilterPattern :: Lens' MetricFilter (Maybe Text) Source
Undocumented member.
mfMetricTransformations :: Lens' MetricFilter (Maybe (NonEmpty MetricTransformation)) Source
Undocumented member.
MetricFilterMatchRecord
data MetricFilterMatchRecord Source
See: metricFilterMatchRecord smart constructor.
metricFilterMatchRecord :: MetricFilterMatchRecord Source
Creates a value of MetricFilterMatchRecord with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
mfmrExtractedValues :: Lens' MetricFilterMatchRecord (HashMap Text Text) Source
Undocumented member.
mfmrEventMessage :: Lens' MetricFilterMatchRecord (Maybe Text) Source
Undocumented member.
mfmrEventNumber :: Lens' MetricFilterMatchRecord (Maybe Integer) Source
Undocumented member.
MetricTransformation
data MetricTransformation Source
See: metricTransformation smart constructor.
Arguments
| :: Text | |
| -> Text | |
| -> Text | |
| -> MetricTransformation |
Creates a value of MetricTransformation with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
mtMetricName :: Lens' MetricTransformation Text Source
Undocumented member.
mtMetricNamespace :: Lens' MetricTransformation Text Source
Undocumented member.
mtMetricValue :: Lens' MetricTransformation Text Source
Undocumented member.
OutputLogEvent
data OutputLogEvent Source
See: outputLogEvent smart constructor.
outputLogEvent :: OutputLogEvent Source
Creates a value of OutputLogEvent with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
oleIngestionTime :: Lens' OutputLogEvent (Maybe Natural) Source
Undocumented member.
oleMessage :: Lens' OutputLogEvent (Maybe Text) Source
Undocumented member.
oleTimestamp :: Lens' OutputLogEvent (Maybe Natural) Source
Undocumented member.
RejectedLogEventsInfo
data RejectedLogEventsInfo Source
See: rejectedLogEventsInfo smart constructor.
rejectedLogEventsInfo :: RejectedLogEventsInfo Source
Creates a value of RejectedLogEventsInfo with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
rleiTooOldLogEventEndIndex :: Lens' RejectedLogEventsInfo (Maybe Int) Source
Undocumented member.
rleiTooNewLogEventStartIndex :: Lens' RejectedLogEventsInfo (Maybe Int) Source
Undocumented member.
rleiExpiredLogEventEndIndex :: Lens' RejectedLogEventsInfo (Maybe Int) Source
Undocumented member.
SearchedLogStream
data SearchedLogStream Source
An object indicating the search status of a log stream in a
FilterLogEvents request.
See: searchedLogStream smart constructor.
searchedLogStream :: SearchedLogStream Source
Creates a value of SearchedLogStream with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
slsLogStreamName :: Lens' SearchedLogStream (Maybe Text) Source
The name of the log stream.
slsSearchedCompletely :: Lens' SearchedLogStream (Maybe Bool) Source
Indicates whether all the events in this log stream were searched or more data exists to search by paginating further.
SubscriptionFilter
data SubscriptionFilter Source
See: subscriptionFilter smart constructor.
subscriptionFilter :: SubscriptionFilter Source
Creates a value of SubscriptionFilter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
sfCreationTime :: Lens' SubscriptionFilter (Maybe Natural) Source
Undocumented member.
sfFilterName :: Lens' SubscriptionFilter (Maybe Text) Source
Undocumented member.
sfDestinationARN :: Lens' SubscriptionFilter (Maybe Text) Source
Undocumented member.
sfLogGroupName :: Lens' SubscriptionFilter (Maybe Text) Source
Undocumented member.
sfFilterPattern :: Lens' SubscriptionFilter (Maybe Text) Source
Undocumented member.